from distutils.core import setup

setup(
      name = 'rockinglists',
      version = '1.1.1',
      py_modules = ['rockinglists'],
      author  =  'ateev',
      author_email = 'ateev@live.com',
      url = 'zedai.wordpress.com', 
      description = 'simple list functions',
     )
